==> openshift-model-operatorhub-5.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/RegistryServiceStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RegistryServiceStatusBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus,io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusBuilder>{
  public RegistryServiceStatusBuilder() {
    this(false);
  }
  public RegistryServiceStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new RegistryServiceStatus(), validationEnabled);
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RegistryServiceStatus(), validationEnabled);
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus instance) {
    this(fluent, instance, false);
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCreatedAt(instance.getCreatedAt()); 
    fluent.withPort(instance.getPort()); 
    fluent.withProtocol(instance.getProtocol()); 
    fluent.withServiceName(instance.getServiceName()); 
    fluent.withServiceNamespace(instance.getServiceNamespace()); 
    this.validationEnabled = validationEnabled; 
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus instance) {
    this(instance,false);
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCreatedAt(instance.getCreatedAt()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.withServiceName(instance.getServiceName()); 
    this.withServiceNamespace(instance.getServiceNamespace()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus build() {
    RegistryServiceStatus buildable = new RegistryServiceStatus(fluent.getCreatedAt(),fluent.getPort(),fluent.getProtocol(),fluent.getServiceName(),fluent.getServiceNamespace());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RegistryServiceStatusBuilder that = (RegistryServiceStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/RegistryServiceStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RegistryServiceStatusBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus,io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusBuilder>{
  public RegistryServiceStatusBuilder() {
    this(false);
  }
  public RegistryServiceStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new RegistryServiceStatus(), validationEnabled);
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RegistryServiceStatus(), validationEnabled);
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus instance) {
    this(fluent, instance, false);
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCreatedAt(instance.getCreatedAt()); 
    fluent.withPort(instance.getPort()); 
    fluent.withProtocol(instance.getProtocol()); 
    fluent.withServiceName(instance.getServiceName()); 
    fluent.withServiceNamespace(instance.getServiceNamespace()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus instance) {
    this(instance,false);
  }
  public RegistryServiceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCreatedAt(instance.getCreatedAt()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.withServiceName(instance.getServiceName()); 
    this.withServiceNamespace(instance.getServiceNamespace()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus build() {
    RegistryServiceStatus buildable = new RegistryServiceStatus(fluent.getCreatedAt(),fluent.getPort(),fluent.getProtocol(),fluent.getServiceName(),fluent.getServiceNamespace());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RegistryServiceStatusBuilder that = (RegistryServiceStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
